@@ -3,16 +3,18 @@ from .utils import get_url, get_info, is_token_tag
 from .token import get_token_list
 
 class Client:
-    def __init__(self, everpay_server_url):
+    def __init__(self, everpay_server_url, timeout=2):
         if everpay_server_url.endswith('/'):
             everpay_server_url = everpay_server_url[:-1]
         self.api_server = everpay_server_url
 
         info_url = get_url(self.api_server, '/info')
-        self.info = get_info(info_url)
+        self.info = get_info(info_url, timeout=timeout)
         self.eth_chain_id = self.info['ethChainID']
         self.fee_recipient = self.info['feeRecipient']
         self.symbol_to_tokens, self.tag_to_tokens = get_token_list(self.info)
+
+        self.timeout = timeout
         
     def get_info(self):
        return self.info
@@ -61,20 +63,31 @@ class Client:
         else:
             path = '/balances/%s' % account
         url = get_url(self.api_server, path)
-        return requests.get(url).json()
+        return requests.get(url, timeout=self.timeout).json()
 
-    def get_txs(self, account='', order='desc', page=None):
+    def get_txs(self, address='', start_cursor=0, order_by='desc', limit=10, token_tag='', action='', without_action=''):
+        params = {}
+        if start_cursor > 0:
+            params['cursor'] = start_cursor
+        if order_by:
+            params['order'] = order_by
+        if limit > 0:
+            params['count'] = limit
+        if token_tag != '':
+            params['tokenTag'] = token_tag
+        if action != '':
+            params['action'] = action
+        if without_action != '':
+            params['withoutAction'] = without_action
+        
         path = '/txs'
-        if account:
-            path = '/txs/%s' % account
-        if page:
-            path = '%s/?order=%s&page=%i' % (path, order, int(page))
-        else:
-            path = '%s/?order=%s' % (path, order)
+        if address != '':
+            path = '/txs/%s' % address
+        
         url = get_url(self.api_server, path)
-        return requests.get(url).json()
+        return requests.get(url, params=params, timeout=self.timeout).json()
 
     def get_tx(self, hash):
         path = '/tx/%s' % hash
         url = get_url(self.api_server, path)
-        return requests.get(url).json()
\ No newline at end of file
+        return requests.get(url, timeout=self.timeout).json()
\ No newline at end of file
