@@ -1,11 +1,17 @@
-import requests, time
 def get_token_list(info):
-    tokens = {}    
+    symbol_to_tokens = {}
+    tag_to_tokens = {}    
     for t in info['tokenList']:
         symbol = t['symbol']
         token = Token(t['tag'], t['chainType'], t['chainID'], symbol, t['id'], t['decimals'])
-        tokens[symbol] = token
-    return tokens
+        
+        if symbol_to_tokens.get(symbol):
+            symbol_to_tokens[symbol].append(token)
+        else:
+            symbol_to_tokens[symbol] = [token, ]
+     
+        tag_to_tokens[t['tag']] = token
+    return symbol_to_tokens, tag_to_tokens
 
 class Token:
     def __init__(self, token_tag, chain_type, chain_id, token_symbol, token_id, token_decimals):
