@@ -40,7 +40,7 @@ class Transaction:
     def get_ever_hash(self):
         message = encode_defunct(text=str(self))
         message_hash = _hash_eip191_message(message)
-        return w3.toHex(message_hash)
+        return w3.to_hex(message_hash)
 
     def to_dict(self):
         return {
@@ -61,9 +61,13 @@ class Transaction:
             'sig': self.sig
         }
 
-    def post(self, api_host):
+    def post(self, api_host, timeout=2):
         url = api_host + '/tx'
         if not self.sig:
             raise Exception(self.tx_id, 'no signature.')
         #print('post_data:', self.to_dict())
-        return requests.post(url, json=self.to_dict())
\ No newline at end of file
+        return requests.post(url, json=self.to_dict(), timeout=timeout)
+
+def sign_tx(tx, signer):
+    tx.sig = signer.sign(str(tx))
+    return tx
\ No newline at end of file
